#!/usr/bin/env python3

# This amulet test deploys the bundles.yaml file in this directory.

import os
import unittest
import yaml
import amulet
import time

seconds_to_wait = 1200


class BundleTest(unittest.TestCase):
    """Create a class for testing the charm in the unit test framework."""
    @classmethod
    def setUpClass(cls):
        """Set up an amulet deployment using the bundle."""
        origin = os.environ.get('LANDSCAPE_CLIENT_CHARM_ORIGIN', None)
        d = amulet.Deployment()
        bundle_path = os.path.join(os.path.dirname(__file__), 'bundles.yaml')
        with open(bundle_path, 'r') as bundle_file:
            contents = yaml.safe_load(bundle_file)
            d.load(contents)
        if origin is not None:
            d.configure("landscape-client", {"origin": origin})
        d.setup(seconds_to_wait)
        d.sentry.wait(seconds_to_wait)
        cls.d = d

    def test_deployed(self):
        """Test to see if the bundle deployed successfully."""
        self.assertTrue(self.d.deployed)

    def test_wait_for_succes_in_log(self):
        """landscape-client should successfully register."""
        tail = "tail -20 /var/log/juju/unit-landscape-client*.log"
        grep = "grep 'System successfully registered'"
        # Only principal units are addressable in this way.
        for i in range(20):
            result = self.d.sentry.unit['ubuntu/0'].run(
                "%s | %s" % (tail, grep))
            if result[1] != 0:
                time.sleep(10)
            else:
                # success, fall through
                break
        else:
            raise AssertionError("Could not verify registration of the client")


if __name__ == '__main__':
    unittest.main()
